@@ -4,11 +4,7 @@
 <!--BEGIN STABILITY BANNER-->---
 
 
-![Stability: Experimental](https://img.shields.io/badge/stability-Experimental-important.svg?style=for-the-badge)
-
-> All classes are under active development and subject to non-backward compatible changes or removal in any
-> future version. These are not subject to the [Semantic Versioning](https://semver.org/) model.
-> This means that while you may use them, you may need to update your source code when upgrading to a newer version of this package.
+![Stability: Stable](https://img.shields.io/badge/cfn--resources-stable-success.svg?style=for-the-badge)
 
 ---
 <!--END STABILITY BANNER-->
@@ -76,8 +72,9 @@ new CloudFrontToApiGateway(scope: Construct, id: string, props: CloudFrontToApiG
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
 |existingApiGatewayObj|[`api.RestApi`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-apigateway.RestApi.html)|The regional API Gateway that will be fronted with the CloudFront|
-|cloudFrontDistributionProps?|[`cloudfront.DistributionProps | any`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-cloudfront.DistributionProps.html)|Optional user provided props to override the default props for CloudFront Distribution|
+|cloudFrontDistributionProps?|[`cloudfront.DistributionProps \| any`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-cloudfront.DistributionProps.html)|Optional user provided props to override the default props for CloudFront Distribution|
 |insertHttpSecurityHeaders?|`boolean`|Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from CloudFront|
+|cloudFrontLoggingBucketProps?|[`s3.BucketProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.BucketProps.html)|Optional user provided props to override the default props for the CloudFront Logging Bucket.|
 
 ## Pattern Properties
 
@@ -141,6 +138,7 @@ class CloudFrontToApiGateway(
         *,
         existing_api_gateway_obj: aws_cdk.aws_apigateway.RestApi,
         cloud_front_distribution_props: typing.Any = None,
+        cloud_front_logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
         insert_http_security_headers: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''
@@ -148,6 +146,7 @@ class CloudFrontToApiGateway(
         :param id: - this is a a scope-unique id.
         :param existing_api_gateway_obj: Existing instance of api.RestApi object. Default: - None
         :param cloud_front_distribution_props: Optional user provided props to override the default props. Default: - Default props are used
+        :param cloud_front_logging_bucket_props: Optional user provided props to override the default props for the CloudFront Logging Bucket. Default: - Default props are used
         :param insert_http_security_headers: Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront. Default: - true
 
         :access: public
@@ -157,6 +156,7 @@ class CloudFrontToApiGateway(
         props = CloudFrontToApiGatewayProps(
             existing_api_gateway_obj=existing_api_gateway_obj,
             cloud_front_distribution_props=cloud_front_distribution_props,
+            cloud_front_logging_bucket_props=cloud_front_logging_bucket_props,
             insert_http_security_headers=insert_http_security_headers,
         )
 
@@ -189,6 +189,7 @@ class CloudFrontToApiGateway(
     name_mapping={
         "existing_api_gateway_obj": "existingApiGatewayObj",
         "cloud_front_distribution_props": "cloudFrontDistributionProps",
+        "cloud_front_logging_bucket_props": "cloudFrontLoggingBucketProps",
         "insert_http_security_headers": "insertHttpSecurityHeaders",
     },
 )
@@ -198,20 +199,26 @@ class CloudFrontToApiGatewayProps:
         *,
         existing_api_gateway_obj: aws_cdk.aws_apigateway.RestApi,
         cloud_front_distribution_props: typing.Any = None,
+        cloud_front_logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
         insert_http_security_headers: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''
         :param existing_api_gateway_obj: Existing instance of api.RestApi object. Default: - None
         :param cloud_front_distribution_props: Optional user provided props to override the default props. Default: - Default props are used
+        :param cloud_front_logging_bucket_props: Optional user provided props to override the default props for the CloudFront Logging Bucket. Default: - Default props are used
         :param insert_http_security_headers: Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront. Default: - true
 
         :summary: The properties for the CloudFrontToApiGateway Construct
         '''
+        if isinstance(cloud_front_logging_bucket_props, dict):
+            cloud_front_logging_bucket_props = aws_cdk.aws_s3.BucketProps(**cloud_front_logging_bucket_props)
         self._values: typing.Dict[str, typing.Any] = {
             "existing_api_gateway_obj": existing_api_gateway_obj,
         }
         if cloud_front_distribution_props is not None:
             self._values["cloud_front_distribution_props"] = cloud_front_distribution_props
+        if cloud_front_logging_bucket_props is not None:
+            self._values["cloud_front_logging_bucket_props"] = cloud_front_logging_bucket_props
         if insert_http_security_headers is not None:
             self._values["insert_http_security_headers"] = insert_http_security_headers
 
@@ -234,6 +241,17 @@ class CloudFrontToApiGatewayProps:
         result = self._values.get("cloud_front_distribution_props")
         return typing.cast(typing.Any, result)
 
+    @builtins.property
+    def cloud_front_logging_bucket_props(
+        self,
+    ) -> typing.Optional[aws_cdk.aws_s3.BucketProps]:
+        '''Optional user provided props to override the default props for the CloudFront Logging Bucket.
+
+        :default: - Default props are used
+        '''
+        result = self._values.get("cloud_front_logging_bucket_props")
+        return typing.cast(typing.Optional[aws_cdk.aws_s3.BucketProps], result)
+
     @builtins.property
     def insert_http_security_headers(self) -> typing.Optional[builtins.bool]:
         '''Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront.
